--imports
local assert = require("justo.assert")
local justo = require("justo")
local suite, test, init = justo.suite, justo.test, justo.init
local Trans = require("dogma.trans.js.Trans")
local Parser = require("dogma.syn.Parser")

--Suite.
return suite("dogma.trans.js.Trans", function()
  local trans, parser

  ---------------
  -- dogmalang --
  ---------------
  suite("dogmalang", function()
    init("*", function()
      parser = Parser.new()
      trans = Trans.new()
      trans:transform(parser)
    end):title("Create transformer")

    test("not importing", function()
      parser:parse("var [x, y] = 1+2")
      assert(trans:next()):eq("let [x, y] = dogma.getArrayToUnpack((1+2), 2);\n")
    end)

    test("importing", function()
      parser:parse("var [x, y] = 1+2")
      assert(trans:next({importDogmalang = true})):eq([[
import {any, bool, datetime, func, list, map, num, promise, proxy, set, text, abstract, bind, coalesce, dogma, echo, echof, exec, execf, expect, fmt, json, keys, len, os, print, printf, ps, range, remove, sleep, todo, typename, values} from "dogmalang";
let [x, y] = dogma.getArrayToUnpack((1+2), 2);
]])
    end)

    test("importing with #!runWith as 1st proposition", function()
      parser:parse([[
#!/usr/bin/env node
var [x, y] = 1+2
]])
      assert(trans:next({importDogmalang = true})):eq([[
#!/usr/bin/env node
import {any, bool, datetime, func, list, map, num, promise, proxy, set, text, abstract, bind, coalesce, dogma, echo, echof, exec, execf, expect, fmt, json, keys, len, os, print, printf, ps, range, remove, sleep, todo, typename, values} from "dogmalang";
let [x, y] = dogma.getArrayToUnpack((1+2), 2);
]])
    end)
  end)

  ------------------
  -- dogmalangmin --
  ------------------
  suite("dogmalangmin", function()
    init("*", function()
      parser = Parser.new()
      trans = Trans.new({module="dogmalangmin"})
      trans:transform(parser)
    end):title("Create transformer")

    test("importing", function()
      parser:parse("var [x, y] = 1+2")
      assert(trans:next({importDogmalang = true})):eq([[
import {any, bool, datetime, func, list, map, num, promise, proxy, set, text, abstract, bind, coalesce, dogma, echo, echof, expect, fmt, json, keys, len, print, printf, ps, range, remove, sleep, todo, typename, values} from "dogmalangmin";
let [x, y] = dogma.getArrayToUnpack((1+2), 2);
]])
    end)
  end)
end)
